@@ -167,12 +167,13 @@ class GCP:
     Class contains function to handle processes in Google Cloud Platform.
 
     """
+
     def __init__(self):
         pass
 
     @staticmethod
     def upload_to_gcp_bucket(
-            project: str, bucket_name: str, file_name: str, file_path: str
+        project: str, bucket_name: str, file_name: str, file_path: str
     ):
         """
         Uploads a file onto a GCP bucket specified.
@@ -290,7 +291,9 @@ class GCP:
         return credentials
 
     @staticmethod
-    def bq_table_to_dataframe(table_name: str, project_id: str, credentials_path: str = None) -> pd.DataFrame:
+    def bq_table_to_dataframe(
+        table_name: str, project_id: str, credentials_path: str = None
+    ) -> pd.DataFrame:
         """
         Downloads a whole table from a specified BigQuery table as a pandas dataframe.
         Note that the project_id & in_VM param handle the authentication of the relevant credentials;
@@ -328,12 +331,14 @@ class GCP:
         print("Executing query and returning dataframe")
         return (
             bqclient.query(query_string)
-                .result()
-                .to_dataframe(bqstorage_client=bqstorageclient)
+            .result()
+            .to_dataframe(bqstorage_client=bqstorageclient)
         )
 
     @staticmethod
-    def execute_sql_statement(sql_statement: str, table_id: str, query_parameters: list):
+    def execute_sql_statement(
+        sql_statement: str, table_id: str, query_parameters: list = None
+    ):
         """
         Executes a general SQL statement in BigQuery.
 
@@ -357,7 +362,9 @@ class GCP:
 
         query_job = client.query(sql_statement, job_config=job_config)
 
-        print("BigQuery (delete_from_bigquery): Starting job {}".format(query_job.job_id))
+        print(
+            "BigQuery (delete_from_bigquery): Starting job {}".format(query_job.job_id)
+        )
         query_job.result()  # awaits result of job
 
         ## get total number of rows after
@@ -376,19 +383,20 @@ class CloudSQL:
     Class contains functions to handle processes in Cloud SQL.
 
     """
+
     def __init__(self):
         pass
 
     @staticmethod
     def create_cloud_sql_pool(
-            db_user: str,
-            db_pass: str,
-            db_hostname: str,
-            db_port: str,
-            db_name: str,
-            sslcert_path: str,
-            sslkey_path: str,
-            sslrootcert_path: str,
+        db_user: str,
+        db_pass: str,
+        db_hostname: str,
+        db_port: str,
+        db_name: str,
+        sslcert_path: str,
+        sslkey_path: str,
+        sslrootcert_path: str,
     ):
         """
         Establishes connection to a CloudSQL instance using the relevant credentials. Note that the relevant
@@ -452,9 +460,7 @@ class CloudSQL:
         return pool.connect()
 
     @staticmethod
-    def get_data_from_cloud_sql(
-            pool: sqlalchemy.engine, query: str
-    ) -> pd.DataFrame:
+    def get_data_from_cloud_sql(pool: sqlalchemy.engine, query: str) -> pd.DataFrame:
         """
         Gets data in the form of a pandas dataframe from the connection established using the
         connect_to_CloudSQL function.
@@ -479,7 +485,7 @@ class CloudSQL:
 
     @staticmethod
     def upload_df_to_cloud_sql(
-            df: pd.DataFrame, cloud_sql_table_name: str, pool: sqlalchemy.engine
+        df: pd.DataFrame, cloud_sql_table_name: str, pool: sqlalchemy.engine
     ):
         """
         Uploads a dataframe to a specified table in a CloudSQL instance based on a prior established connection.
@@ -507,6 +513,7 @@ class General:
     Class contains generic functions that may be useful.
 
     """
+
     def __init__(self):
         pass
 
@@ -557,4 +564,4 @@ class General:
         context = ssl.create_default_context()
         with smtplib.SMTP_SSL(smtp_server, port, context=context) as server:
             server.login(sender_email, password)
-            server.sendmail(sender_email, receiver_email, message)
\ No newline at end of file
+            server.sendmail(sender_email, receiver_email, message)
